package com.wsj.vibratedemo;

import android.content.Context;
import android.os.Vibrator;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private EditText et_vibrateTime, et_intervalTime, et_vibrateCount;
    private Button btn_vibrate, btn_loopVibrate, btn_cancel;

    private Vibrator mVibrator;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        initView();
        initEvents();
    }

    private void initView() {
        mVibrator = (Vibrator) getSystemService(Context.VIBRATOR_SERVICE);

        et_vibrateTime = getView(R.id.et_vibrateTime);
        et_intervalTime = getView(R.id.et_intervalTime);
        et_vibrateCount = getView(R.id.et_vibrateCount);

        btn_vibrate = getView(R.id.btn_vibrate);
        btn_loopVibrate = getView(R.id.btn_loopVibrate);
        btn_cancel = getView(R.id.btn_cancel);
    }

    private void initEvents() {
        btn_vibrate.setOnClickListener(this);
        btn_loopVibrate.setOnClickListener(this);
        btn_cancel.setOnClickListener(this);
    }

    private <T extends View> T getView(int id) {
        return (T) findViewById(id);
    }

    /**
     * 开启震动
     * @param interval 震动间隔
     * @param vibrate 震动时间
     * @param count 震动次数
     * @param repeat 是否循环震动
     */
    private void vibrate(long interval, long vibrate, int count, boolean repeat) {
        long[] pattern = new long[count * 2];

        for(int i=0; i<count * 2; i++) {
            if(i % 2 == 0) {
                pattern[i] = interval;
            } else {
                pattern[i] = vibrate;
            }
        }

        if(repeat) {
            mVibrator.vibrate(pattern, 0);
        } else {
            mVibrator.vibrate(pattern, -1);
        }
    }

    @Override
    public void onClick(View v) {
        String vibrateTime = et_vibrateTime.getText().toString().trim();
        String intervalTime = et_intervalTime.getText().toString().trim();
        String countStr = et_vibrateCount.getText().toString().trim();

        long vibTime = 200, itvTime = 200;
        int count = 2;

        try {
            if (!TextUtils.isEmpty(vibrateTime)) {
                vibTime = Long.valueOf(vibrateTime);
            }

            if (!TextUtils.isEmpty(intervalTime)) {
                itvTime = Long.valueOf(intervalTime);
            }

            if (!TextUtils.isEmpty(countStr)) {
                count = Integer.valueOf(countStr);
            }

            switch (v.getId()) {
                case R.id.btn_vibrate: // 震动
                    vibrate(itvTime, vibTime, count, false);
                    break;
                case R.id.btn_loopVibrate: // 循环震动
                    vibrate(itvTime, vibTime, count, true);
                    break;
                case R.id.btn_cancel: // 取消
                    mVibrator.cancel();
                    break;
            }
        } catch (NumberFormatException e) {
            showToast(R.string.param_error);
        }
    }

    private Toast toast;
    private void showToast(String msg) {
        if(toast != null) {
            toast.cancel();
        }
        toast = Toast.makeText(this, msg, Toast.LENGTH_SHORT);
        toast.show();
    }

    private void showToast(int resId) {
        showToast(getString(resId));
    }
}
